@@ -18,11 +18,16 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
     """Base class for Doinikov (viscous fluid-viscous sphere; 1994)
 
     .. note::
-       For all models the condition :math:`|x| \\ll 1` must hold.
+       For all implemented solution the small particle limit
+       :math:`|x| \\ll 1` is assumed.
 
-       If :attr:`small_viscous_boundary_layer` is set to `True` than in
-       addition :math:`|x| \\ll |x_v| \\ll 1` must hold. If set to
-       `False` than :math:`|x| \\ll 1 \\ll |x_v|` must hold.
+       If :attr:`small_viscous_boundary_layer` the ARF is computed for the
+       limiting case :math:`|x| \\ll 1 \\ll |x_v|`. If
+       :attr:`large_viscous_boundary_layer` is set to `True`
+       then the ARF is computed for the limiting case
+       :math:`|x| \\ll |x_v| \\ll 1`. Setting both option to `False` will
+       lead to error since the solution for an arbitrary boundary layer
+       thickness is implemented.
 
        Both values will be logged in the `info.log` when calling
        :meth:`acoustic_radiation_force`. These conditions will not be
@@ -33,8 +38,8 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
     :param radius: Radius of the solid [m]
     :param rho_s: Density of the fluid-like solid [kg/m^3]
     :param c_s: Speed of sound of the solid [m/s]
-    :param eta_p: shear viscosity of the solid [Pa s]
-    :param zeta_p: bulk viscosity of the solid [Pa s]
+    :param eta_s: shear viscosity of the solid [Pa s]
+    :param zeta_s: bulk viscosity of the solid [Pa s]
     :param rho_f: Density of the fluid [kg/m^3]
     :param c_f: Speed of sound of the fluid [m/s]
     :param eta_f: shear viscosity fluid [Pa s]
@@ -42,8 +47,8 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
     :param p_0: Pressure amplitude of the field [Pa]
     :param wave_type: Type of wave, travel(l)ing or standing
     :param position: Position within the standing wave field [m]
-    :param small_viscous_boundary_layer: :math:`x_v \\ll 1`
-    :param gas_bubble: solid is a gas bubble in a liquid
+    :param small_viscous_boundary_layer: :math:`x_v \\gg 1`
+    :param large_viscous_boundary_layer: :math:`x_v \\ll 1`
     :param small_particle_limit: using the limiting cases for the ARF
     :param N_max: Highest order mode
     """
@@ -52,14 +57,14 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
         self, frequency: Union[Frequency, float, int],
         radius: Union[Sphere, float, int],
         rho_s: float, c_s: float,
-        eta_p: float, zeta_p: float,
+        eta_s: float, zeta_s: float,
         rho_f: float, c_f: float,
         eta_f: float, zeta_f: float,
         p_0: float,
-        wave_type: WaveTypes = WaveTypes.STANDING,
+        wave_type: WaveTypes,
         position: Optional[float] = None,
-        small_viscous_boundary_layer: bool = True,
-        gas_bubble: bool = False,
+        small_viscous_boundary_layer: bool = False,
+        large_viscous_boundary_layer: bool = False,
         small_particle_limit: bool = True,
         N_max: int = 5,
     ) -> None:
@@ -70,7 +75,7 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
         BaseSphereFrequencyComposite.__init__(self, frequency, radius)
         ScatteringField.__init__(
             self, frequency, radius,
-            rho_s, c_s, eta_p, zeta_p,
+            rho_s, c_s, eta_s, zeta_s,
             rho_f, c_f, eta_f, zeta_f,
             p_0, wave_type, position, N_max,
         )
@@ -81,132 +86,67 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
             small_particle_limit,
             'small particle limit',
         )
+        self._check_boundary_layer(
+            small_viscous_boundary_layer,
+            large_viscous_boundary_layer,
+        )
         self._small_viscous_boundary_layer = PassiveVariable(
             small_viscous_boundary_layer,
             'small viscous boundary layer limit',
         )
-
-        self._check_gas_bubble(gas_bubble)
-        self._gas_bubble = PassiveVariable(
-            gas_bubble,
-            'particle is a gas bubble',
+        self._large_viscous_boundary_layer = PassiveVariable(
+            large_viscous_boundary_layer,
+            'large viscous boundary layer limit',
         )
 
-        # dependen variables
+        # Dependent variables
         self._norm_delta = ActiveVariable(
             self._compute_norm_delta,
-            'normalized boundary layer thickness',
+            'normalized boundary layer '
+            'thickness',
         )
-
         self._mu = ActiveVariable(
             self._compute_mu,
             '(density * viscosity) ratio',
         )
-
         self._kappa_t = ActiveVariable(
             self._compute_kappa_t,
             'compressibility ratio',
         )
-
         self._eta_t = ActiveVariable(
-            self._compute_eta_t,
-            'dynamic viscosity ratio',
+            self._compute_eta_t, 'dynamic viscosity ratio',
         )
-
         self._zeta_t = ActiveVariable(
-            self._compute_zeta_t,
-            'bulk viscosity ratio',
-        )
-
-        self._f1 = ActiveVariable(
-            self._compute_f1,
-            'f1 ARF factor; B.2.1',
-        )
-
-        self._f2 = ActiveVariable(
-            self._compute_f2,
-            'f2 ARF factor; B.2.1',
-        )
-
-        self._f3 = ActiveVariable(
-            self._compute_f3,
-            'f3 ARF factor; B.2.1',
-        )
-
-        self._G = ActiveVariable(
-            self._compute_G,
-            'G ARF factor; eq. 7.9',
-        )
-
-        self._S1 = ActiveVariable(
-            self._compute_S1,
-            'S1 ARF factor; eq. 7.10',
-        )
-
-        self._S2 = ActiveVariable(
-            self._compute_S2,
-            'S2 ARF factor; eq. 7.11',
-        )
-
-        self._S3 = ActiveVariable(
-            self._compute_S3,
-            'S3 ARF factor; eq. 7.12',
-        )
-
-        self._f4 = ActiveVariable(
-            self._compute_f4,
-            'f4 ARF factor; B.2.1',
-        )
-
-        self._g1 = ActiveVariable(
-            self._compute_g1,
-            'g1 ARF factor; B.2.1',
-        )
-
-        self._g2 = ActiveVariable(
-            self._compute_g2,
-            'g2 ARF factor; B.2.1',
-        )
-
-        self._g3 = ActiveVariable(
-            self._compute_g3,
-            'g3 ARF factor; B.2.1',
-        )
-
-        self._g4 = ActiveVariable(
-            self._compute_g4,
-            'g4 ARF factor; B.2.1',
-        )
-
-        self._g5 = ActiveVariable(
-            self._compute_g5,
-            'g5 ARF factor; B.2.1',
-        )
-
-        self._g6 = ActiveVariable(
-            self._compute_g6,
-            'g6 ARF factor; B.2.1',
-        )
-
-        self._g7 = ActiveVariable(
-            self._compute_g7,
-            'g7 ARF factor; B.2.1',
+            self._compute_zeta_t, 'bulk viscosity ratio',
         )
+        self._f1 = ActiveVariable(self._compute_f1, 'f1 ARF factor; B.2.1')
+        self._f2 = ActiveVariable(self._compute_f2, 'f2 ARF factor; B.2.1')
+        self._f3 = ActiveVariable(self._compute_f3, 'f3 ARF factor; B.2.1')
+        self._G = ActiveVariable(self._compute_G, 'G ARF factor; eq. 7.9')
+        self._S1 = ActiveVariable(self._compute_S1, 'S1 ARF factor; eq. 7.10')
+        self._S2 = ActiveVariable(self._compute_S2, 'S2 ARF factor; eq. 7.11')
+        self._S3 = ActiveVariable(self._compute_S3, 'S3 ARF factor; eq. 7.12')
+        self._f4 = ActiveVariable(self._compute_f4, 'f4 ARF factor; B.2.1')
+        self._g1 = ActiveVariable(self._compute_g1, 'g1 ARF factor; B.2.1')
+        self._g2 = ActiveVariable(self._compute_g2, 'g2 ARF factor; B.2.1')
+        self._g3 = ActiveVariable(self._compute_g3, 'g3 ARF factor; B.2.1')
+        self._g4 = ActiveVariable(self._compute_g4, 'g4 ARF factor; B.2.1')
+        self._g5 = ActiveVariable(self._compute_g5, 'g5 ARF factor; B.2.1')
+        self._g6 = ActiveVariable(self._compute_g6, 'g6 ARF factor; B.2.1')
+        self._g7 = ActiveVariable(self._compute_g7, 'g7 ARF factor; B.2.1')
 
+        # Dependencies
         self._G.is_computed_by(self._S1, self._S2, self._S3)
         self._S1.is_computed_by(
-            self._kappa_t,
-            self.fluid._rho_f, self.solid._rho_f,
+            self._kappa_t, self.fluid._rho_f, self.scatterer._rho_f,
         )
         self._S2.is_computed_by(self._f1, self._f2, self._f4)
         self._S3.is_computed_by(
-            self._f1, self._f3, self._f4,
-            self.fluid._rho_f, self.solid._rho_f,
-            self._kappa_t, self._eta_t,
+            self._f1, self._f3, self._f4, self.fluid._rho_f,
+            self.scatterer._rho_f, self._kappa_t, self._eta_t,
         )
-
-        self._eta_t.is_computed_by(self.solid._eta_f, self.fluid._eta_f)
-        self._zeta_t.is_computed_by(self.solid._zeta_f, self.fluid._zeta_f)
+        self._eta_t.is_computed_by(self.scatterer._eta_f, self.fluid._eta_f)
+        self._zeta_t.is_computed_by(self.scatterer._zeta_f, self.fluid._zeta_f)
         self._f1.is_computed_by(self._g1, self._g7)
         self._f2.is_computed_by(self._g1, self._g2, self._g5)
         self._f3.is_computed_by(self._g3, self._g6, self._g7)
@@ -218,19 +158,14 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
         self._g5.is_computed_by(self._eta_t)
         self._g6.is_computed_by(self._eta_t)
         self._g7.is_computed_by(self._g6)
-
-        self._norm_delta.is_computed_by(
-            self.fluid._delta, self.sphere._R_0,
-        )
-
+        self._norm_delta.is_computed_by(self.fluid._delta, self.sphere._R_0)
         self._kappa_t.is_computed_by(
-            self.fluid._rho_f, self.fluid._c_f,
-            self.solid._rho_f, self.solid._c_f,
+            self.fluid._rho_f, self.fluid._c_f, self.scatterer._rho_f,
+            self.scatterer._c_f,
         )
-
         self._mu.is_computed_by(
-            self.fluid._rho_f, self.fluid._eta_f,
-            self.solid._rho_f, self.solid._eta_f,
+            self.fluid._rho_f, self.fluid._eta_f, self.scatterer._rho_f,
+            self.scatterer._eta_f,
         )
 
         # logging
@@ -241,13 +176,14 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
         return (
             f'Donikov1994Rigid.ARF(frequency={self.f}, radius={self.R_0}, '
             f'rho_s={self.rho_s}, c_s={self.c_s}, '
-            f'eta_p={self.eta_p}, zeta_p={self.zeta_p}, '
+            f'eta_s={self.eta_s}, zeta_s={self.zeta_s}, '
             f'rho_f={self.rho_f}, c_f={self.c_f}, '
             f'eta_f={self.eta_f}, zeta_f={self.zeta_f}, '
             f'p_0={self.p_0}, position={self.position}, {self.wave_type}, '
             f'small_viscous_boundary_layer='
             f'{self.small_viscous_boundary_layer}, '
-            f'gas_bubble={self.gas_bubble}, '
+            f'large_viscous_boundary_layer='
+            f'{self.large_viscous_boundary_layer}, '
             f'small_particle_limit={self.small_particle_limit}, '
             f'N_max={self.N_max})'
         )
@@ -266,18 +202,13 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
             'small_viscous_boundary_layer',
             self.small_viscous_boundary_layer, None,
         )
-        out += SF.get_str_text(
-            'Gas bubble',
-            'gas_bubble',
-            self.gas_bubble, None,
-        )
         out += 'Backgroundfield\n'
         out += SF.get_str_text('Frequency', 'f', self.f, 'Hz')
         out += SF.get_str_text('Pressure', 'p_0', self.p_0, 'Pa')
         out += SF.get_str_text('Wavetype', 'wave_type', self.wave_type, None)
         out += SF.get_str_text(
             'Position', 'd',
-            self.position, 'Pa',
+            self.position, '',
         )
         out += SF.get_str_text(
             'Wavelength', 'lambda',
@@ -324,15 +255,19 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
             self.kappa_s, '1/Pa',
         )
         out += SF.get_str_text(
-            'Shear viscosity', 'eta_p',
-            self.eta_p, '1/Pa',
+            'Shear viscosity', 'eta_s',
+            self.eta_s, '1/Pa',
         )
         out += SF.get_str_text(
-            'Bulk viscosity', 'zeta_p',
-            self.zeta_p, '1/Pa',
+            'Bulk viscosity', 'zeta_s',
+            self.zeta_s, '1/Pa',
         )
         return out
 
+    # -------------------------------------------------------------------------
+    # API
+    # -------------------------------------------------------------------------
+
     def acoustic_radiation_force(self) -> float:
         """Acoustic radiation fore in [N]
 
@@ -341,17 +276,22 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
         :raises ValueError: Non supported :attr:`~osaft.solutions.\
 Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
         """
+        self._check_boundary_layer(
+            self.small_viscous_boundary_layer,
+            self.large_viscous_boundary_layer,
+        )
         if not isinstance(self.wave_type, WaveTypes):
             raise WrongWaveTypeError
-
-        # we do not need to test for gas_bubble yet because this solution right
-        # now not permitted
         if self.small_viscous_boundary_layer:
-            return self._liquid_in_liquid_small_delta()
+            return self._arf_small_particle_small_delta()
         else:
-            return self._liquid_in_liquid()
+            return self._arf_small_particle_large_delta()
 
-    def _liquid_in_liquid_small_delta(self) -> float:
+    # -------------------------------------------------------------------------
+    # Acoustic radiation force
+    # -------------------------------------------------------------------------
+
+    def _arf_small_particle_large_delta(self) -> float:
         """ Eq. 7.1 for WaveTypes.TRAVELLING; Eq. 7.8 for WaveTypes.STANDING
         """
         log.info(
@@ -360,16 +300,16 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
         )
 
         if self.wave_type == WaveTypes.TRAVELLING:
-            out = 5 - 2 * self.kappa_t - 8 * self._f1.value
+            out = 5 - 2 * self.kappa_t - 8 * self.f1
 
             out *= 1 / 6 * self.norm_delta ** 2
         else:
-            out = self._G.value * self._standing_wave_contribution()
+            out = self.G * self._standing_wave_contribution()
 
         out *= pi * self.field.abs_A_squared * self.rho_f * self.x_0**3
         return out
 
-    def _liquid_in_liquid(self) -> float:
+    def _arf_small_particle_small_delta(self) -> float:
         """ Eq. 6.1 for WaveTypes.TRAVELLING
         """
         log.info(
@@ -390,23 +330,31 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
                 'the same as Yosioka already computed.\n If you are '
                 'interested in this value us the Yosioka class.',
             )
-
         return out
 
     def _standing_wave_contribution(self) -> float:
         return sin(2 * self.k_f.real * self.position)
 
+    # -------------------------------------------------------------------------
+    # User input checks
+    # -------------------------------------------------------------------------
+
     @staticmethod
-    def _check_gas_bubble(value):
-        if value:
+    def _check_boundary_layer(small_delta, large_delta) -> None:
+        if small_delta and large_delta:
+            raise ValueError(
+                'small_viscous_boundary_layer and '
+                'large_viscous_boundary_layer can\'t both be True',
+            )
+        if not small_delta and not large_delta:
             raise NotImplementedError(
-                'You are trying to use the limiting case of a gas bubble '
-                'for this model. However, so far this limiting case is not '
-                'implemented. Feel free to help us to extend this.',
+                'You are trying to use the solution for an arbitrary '
+                'boundary layer thickness. However, so far this solution '
+                'has not implemented. Feel free to help us to extend this.',
             )
 
     @staticmethod
-    def _check_small_particle_limit_value(value):
+    def _check_small_particle_limit_value(value) -> None:
         if not value:
             raise NotImplementedError(
                 'You are trying to use the general solution to the ARF '
@@ -414,6 +362,10 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
                 'are implemented. Feel free to help us to extend this.',
             )
 
+    # -------------------------------------------------------------------------
+    # Getters and Setters for dependent variables
+    # -------------------------------------------------------------------------
+
     @property
     def small_particle_limit(self) -> bool:
         """Use limiting case for ARF calculation
@@ -431,21 +383,6 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
         self._check_small_particle_limit_value(value)
         self._small_particle_limit.value = value
 
-    @property
-    def gas_bubble(self) -> bool:
-        """Use limiting case of a gas bubble as solid
-
-        :getter: returns if solid is a gas bubble
-        :setter: automatically invokes
-            :meth:`osaft.core.variable.BaseVariable.notify`
-        """
-        return self._gas_bubble.value
-
-    @gas_bubble.setter
-    def gas_bubble(self, value):
-        self._check_gas_bubble(value)
-        self._gas_bubble.value = value
-
     @property
     def small_viscous_boundary_layer(self) -> bool:
         """Use limiting case of a small viscous boundary layer :math:`\\delta`
@@ -460,84 +397,170 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
     def small_viscous_boundary_layer(self, value):
         self._small_viscous_boundary_layer.value = value
 
+    @property
+    def large_viscous_boundary_layer(self) -> bool:
+        """Use limiting case of a large viscous boundary layer :math:`\\delta`
+
+        :getter: returns if a large viscous boundary layer case is used
+        :setter: automatically invokes
+            :func:`osaft.core.variable.BaseVariable.notify`
+        """
+        return self._large_viscous_boundary_layer.value
+
+    @large_viscous_boundary_layer.setter
+    def large_viscous_boundary_layer(self, value):
+        self._large_viscous_boundary_layer.value = value
+
+    # -------------------------------------------------------------------------
+    # Dependent variables
+    # -------------------------------------------------------------------------
+
+    @property
+    def eta_t(self):
+        return self._eta_t.value
+
     def _compute_eta_t(self):
-        return self.solid.eta_f / self.fluid.eta_f
+        return self.scatterer.eta_f / self.fluid.eta_f
+
+    @property
+    def zeta_t(self):
+        return self._zeta_t.value
 
     def _compute_zeta_t(self):
-        return self.solid.zeta_f / self.fluid.zeta_f
+        return self.scatterer.zeta_f / self.fluid.zeta_f
+
+    @property
+    def f1(self):
+        return self._f1.value
+
+    def _compute_f1(self):
+        return self.g1 / self.g7
+
+    @property
+    def f2(self):
+        return self._f2.value
+
+    def _compute_f2(self):
+        if self.g1 == 0:  # pragma: no cover
+            return 0
+        return self.g2 * self.g5 / self.g1 / 2
+
+    @property
+    def f3(self):
+        return self._f3.value
+
+    def _compute_f3(self):
+        return self.g3 * self.g6 / self.g7 / 10
+
+    @property
+    def f4(self):
+        return self._f4.value
+
+    def _compute_f4(self):
+        return self.g4 * self.g6 / self.g7 / 2
+
+    @property
+    def G(self):
+        return self._G.value
 
     def _compute_G(self):
-        return (self._S1.value + self._S2.value + self._S3.value) / 3
+        return (self.S1 + self.S2 + self.S3) / 3
+
+    @property
+    def S1(self):
+        return self._S1.value
 
     def _compute_S1(self):
         return 1 - self.kappa_t + 0.9 * (1 - self.rho_s / self.rho_f)
 
-    def _compute_S2(self):
-        out = 2 * self._f2.value - 1
-        out *= 2 * self._f1.value
+    @property
+    def S2(self):
+        return self._S2.value
 
-        out -= 4 * self._f4.value
+    def _compute_S2(self):
+        out = 2 * self.f2 - 1
+        out *= 2 * self.f1
+
+        out -= 4 * self.f4
         return out
 
+    @property
+    def S3(self):
+        return self._S3.value
+
     def _compute_S3(self):
-        out = 3 - 1 / self._eta_t.value
-        out *= -120 * (self._f3.value - self._f4.value)
+        out = 3 - 1 / self.eta_t
+        out *= -120 * (self.f3 - self.f4)
 
-        out += 50 * self._f1.value + 43 - 10 * self.kappa_t
+        out += 50 * self.f1 + 43 - 10 * self.kappa_t
 
         out *= self.rho_s - self.rho_f
-        out /= 30 * self.rho_f * (3 + 2 / self._eta_t.value)
+        out /= 30 * self.rho_f * (3 + 2 / self.eta_t)
 
         return out
 
-    def _compute_f1(self):
-        return self._g1.value / self._g7.value
-
-    def _compute_f2(self):
-        if self._g1.value == 0:
-            return 0
-        return self._g2.value * self._g5.value / self._g1.value / 2
-
-    def _compute_f3(self):
-        return self._g3.value * self._g6.value / self._g7.value / 10
-
-    def _compute_f4(self):
-        return self._g4.value * self._g6.value / self._g7.value / 2
+    @property
+    def g1(self):
+        return self._g1.value
 
     def _compute_g1(self):
-        return self._g5.value * self._g6.value
+        return self.g5 * self.g6
+
+    @property
+    def g2(self):
+        return self._g2.value
 
     def _compute_g2(self):
-        out = 209 + 148 * self._eta_t.value + 48 / self._eta_t.value
-        out *= -1 / 9 / self._zeta_t.value
+        out = 209 + 148 * self.eta_t + 48 / self.eta_t
+        out *= -1 / 9 / self.zeta_t
 
-        out += 19 + 38 * self._eta_t.value - 12 / self._eta_t.value
+        out += 19 + 38 * self.eta_t - 12 / self.eta_t
         return out
 
+    @property
+    def g3(self):
+        return self._g3.value
+
     def _compute_g3(self):
-        out = 25 + 370 * self._eta_t.value - 80 / self._eta_t.value
-        out *= 1 / 9 / self._zeta_t.value
+        out = 25 + 370 * self.eta_t - 80 / self.eta_t
+        out *= 1 / 9 / self.zeta_t
 
-        out -= (12 + 19 * self._eta_t.value + 4 / self._eta_t.value)
+        out -= (12 + 19 * self.eta_t + 4 / self.eta_t)
         return out
 
+    @property
+    def g4(self):
+        return self._g4.value
+
     def _compute_g4(self):
-        out = 5 + 74 * self._eta_t.value - 16 / self._eta_t.value
-        out *= 1 / 9 / self._zeta_t.value
+        out = 5 + 74 * self.eta_t - 16 / self.eta_t
+        out *= 1 / 9 / self.zeta_t
 
-        out -= (3 + 4 / self._eta_t.value)
+        out -= (3 + 4 / self.eta_t)
         return out
 
+    @property
+    def g5(self):
+        return self._g5.value
+
     def _compute_g5(self):
-        out = (1 - self._eta_t.value)
-        out *= 19 + 16 / self._eta_t.value
+        out = (1 - self.eta_t)
+        out *= 19 + 16 / self.eta_t
         return out
 
+    @property
+    def g6(self):
+        return self._g6.value
+
     def _compute_g6(self):
-        return 89 + 48 / self._eta_t.value + 38 * self._eta_t.value
+        return 89 + 48 / self.eta_t + 38 * self.eta_t
+
+    @property
+    def g7(self):
+        return self._g7.value
 
     def _compute_g7(self):
-        return self._g6.value**2
+        return self.g6**2
 
     @property
     def norm_delta(self) -> float:
@@ -557,7 +580,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     def _compute_mu(self):
         out = self.rho_f * self.eta_f
-        out /= self.rho_s * self.eta_p
+        out /= self.rho_s * self.eta_s
         return sqrt(out)
 
     @property
