@@ -30,8 +30,8 @@ class ScatteringField(
     :param radius: Radius of the solid [m]
     :param rho_s: Density of the fluid-like solid [kg/m^3]
     :param c_s: Speed of sound of the sphere [m/s]
-    :param eta_p: shear viscosity of the sphere [Pa s]
-    :param zeta_p: bulk viscosity of the sphere [Pa s]
+    :param eta_s: shear viscosity of the sphere [Pa s]
+    :param zeta_s: bulk viscosity of the sphere [Pa s]
     :param rho_f: Density of the fluid [kg/m^3]
     :param c_f: Speed of sound of the fluid [m/s]
     :param eta_f: shear viscosity [Pa s]
@@ -45,12 +45,10 @@ class ScatteringField(
     def __init__(
         self, frequency: Union[Frequency, float, int],
         radius: Union[Sphere, float, int],
-        rho_s: float, c_s: float, eta_p: float, zeta_p: float,
+        rho_s: float, c_s: float, eta_s: float, zeta_s: float,
         rho_f: float, c_f: float, eta_f: float, zeta_f: float,
-        p_0: float,
-        wave_type: WaveTypes = WaveTypes.STANDING,
-        position: Optional[float] = None,
-        N_max: Optional[int] = 5,
+        p_0: float, wave_type: WaveTypes, position: float,
+        N_max: Optional[int] = 3,
     ) -> None:
         """Constructor method
         """
@@ -59,9 +57,9 @@ class ScatteringField(
         CoefficientMatrix.__init__(self)
         BaseDoinikov1994Compressible.__init__(
             self, frequency, radius,
-            rho_s, c_s, eta_p, zeta_p,
+            rho_s, c_s, eta_s, zeta_s,
             rho_f, c_f, eta_f, zeta_f,
-            p_0, wave_type, position, N_max,
+            p_0, position, wave_type, N_max,
         )
 
         self._create_variables()
@@ -128,10 +126,10 @@ class ScatteringField(
         )
 
         self._x_hat.is_computed_by(
-            self.solid._k_f, self.sphere._R_0,
+            self.scatterer._k_f, self.sphere._R_0,
         )
         self._x_hat_v.is_computed_by(
-            self.solid._k_v, self.sphere._R_0,
+            self.scatterer._k_v, self.sphere._R_0,
         )
 
         # determinants
@@ -203,23 +201,23 @@ class ScatteringField(
         )
         self._m_32.is_computed_by(self._x_v, self.fluid._eta_f)
         self._m_33.is_computed_by(
-            self._x_hat, self.solid._eta_f, self.solid._zeta_f,
-            self.solid._rho_f, self.solid._c_f, self.frequency._omega,
+            self._x_hat, self.scatterer._eta_f, self.scatterer._zeta_f,
+            self.scatterer._rho_f, self.scatterer._c_f, self.frequency._omega,
         )
-        self._m_34.is_computed_by(self._x_hat_v, self.solid._eta_f)
+        self._m_34.is_computed_by(self._x_hat_v, self.scatterer._eta_f)
 
         # matrix entries m_3j
         self._m_41.is_computed_by(self._x, self.fluid._eta_f)
         self._m_42.is_computed_by(self._x_v, self.fluid._eta_f)
-        self._m_43.is_computed_by(self._x_hat, self.solid._eta_f)
-        self._m_44.is_computed_by(self._x_hat_v, self.solid._eta_f)
+        self._m_43.is_computed_by(self._x_hat, self.scatterer._eta_f)
+        self._m_44.is_computed_by(self._x_hat_v, self.scatterer._eta_f)
 
     def __repr__(self):
         return (
             f'Doinikov1994Compressible.ScatteringFiels(frequency={self.f}, '
             f'radius={self.R_0}, '
             f'rho_s={self.rho_s}, c_s={self.c_s}, '
-            f'eta_p={self.eta_p}, zeta_p={self.zeta_p}, '
+            f'eta_s={self.eta_s}, zeta_s={self.zeta_s}, '
             f'rho_f={self.rho_f}, c_f={self.c_f}, '
             f'eta_f={self.eta_f}, zeta_f={self.zeta_f}, '
             f'p_0={self.p_0}, position={self.position}, {self.wave_type}, '
@@ -340,7 +338,7 @@ class ScatteringField(
         N_old = len(self._alpha_n.value)
         for n in full_range(N_old, N):
             if n == 0:
-                tmp1 = 4 * (self.eta_f - self.eta_p) * self.x * self.x_hat
+                tmp1 = 4 * (self.eta_f - self.eta_s) * self.x * self.x_hat
                 tmp1 *= Sp.besselj(1, self.x_hat)
 
                 tmp2 = 1j * self.omega * self.R_0**2
@@ -421,7 +419,7 @@ class ScatteringField(
         N_old = len(self._alpha_hat_n.value)
         for n in full_range(N_old, N):
             if n == 0:
-                tmp1 = 4 * (self.eta_f - self.eta_p) * self.x * self.x_hat
+                tmp1 = 4 * (self.eta_f - self.eta_s) * self.x * self.x_hat
                 tmp2 = 1j * self.omega * self.R_0**2
 
                 # numerator
