@@ -365,6 +365,9 @@ class BaseTest(NumericTestCase):
         self._rho_f = ChangingFloat('rho_f', 1e3, seed, low=0)
         # Compressible Particle (Inviscid Fluid)
         self._c_s = ChangingFloat('c_s', 2.5e3, seed, low=0)
+        # Compressible Particle (Viscous Fluid)
+        self._eta_s = ChangingFloat('eta_s', 1e-3, seed, low=0)
+        self._zeta_s = ChangingFloat('zeta_s', 1e-3, seed, low=0)
         # Viscous Fluid
         self._eta_f = ChangingFloat('eta_f', 1e-2, seed, low=0)
         self._zeta_f = ChangingFloat('zeta_f', 1e-2, seed, low=0)
@@ -398,6 +401,8 @@ class BaseTest(NumericTestCase):
             # Compressible Particle (Inviscid Fluid)
             self._c_s,
             self._rho_s,
+            self._eta_s,
+            self._zeta_s,
             # Viscous Fluid
             self._eta_f,
             self._zeta_f,
@@ -560,6 +565,22 @@ class BaseTest(NumericTestCase):
     def c_s(self, value: float) -> None:
         self._c_s.value = value
 
+    @property
+    def eta_s(self) -> float:
+        return self._eta_s.value
+
+    @eta_s.setter
+    def eta_s(self, value: float) -> None:
+        self._eta_s.value = value
+
+    @property
+    def zeta_s(self) -> float:
+        return self._zeta_s.value
+
+    @zeta_s.setter
+    def zeta_s(self, value: float) -> None:
+        self._eta_s.value = value
+
     @property
     def rho_s(self) -> float:
         return self._rho_s.value
